==> scribus_1.4.6+dfsg.orig.tar.xz: scribus-1.4.6/scribus/plugins/gettext/htmlim/htmlim.h <==
/*
For general Scribus (>=1.3.2) copyright and licensing information please refer
to the COPYING file provided with the program. Following this notice may exist
a copyright and/or license notice that predates the release of Scribus 1.3.2
for which a new license (GPL+exception) is in place.
*/
/***************************************************************************
 *   Copyright (C) 2004 by Riku Leino                                      *
 *   tsoots@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#ifndef HTMLIM_H
#define HTMLIM_H

#include "gtwriter.h"

#include "scconfig.h"
#include "pluginapi.h"

extern "C" PLUGIN_API void GetText(QString filename, QString encoding, bool textOnly, gtWriter *writer);

extern "C" PLUGIN_API QString FileFormatName();

extern "C" PLUGIN_API QStringList FileExtensions();

#include "htmlreader.h"

class HTMLIm 
{
public:
	HTMLIm(QString fname, QString encoding, gtWriter *w, bool textOnly);
	~HTMLIm();
private:
	QString encoding;
	QString filename;
	gtWriter *writer;
	gtParagraphStyle *pstyle;
// 	int defaultFontSize;
	void importText(bool textOnly);
};

#endif // HTMLIM_H

==> scribus_1.5.5+dfsg.orig.tar.xz: scribus-1.5.5/scribus/plugins/gettext/htmlim/htmlim.h <==
/*
For general Scribus (>=1.3.2) copyright and licensing information please refer
to the COPYING file provided with the program. Following this notice may exist
a copyright and/or license notice that predates the release of Scribus 1.3.2
for which a new license (GPL+exception) is in place.
*/
/***************************************************************************
 *   Copyright (C) 2004 by Riku Leino                                      *
 *   tsoots@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#ifndef HTMLIM_H
#define HTMLIM_H

#include "gtwriter.h"

#include "scconfig.h"
#include "pluginapi.h"

extern "C" PLUGIN_API void GetText(const QString& filename, const QString& encoding, bool textOnly, gtWriter *writer);

extern "C" PLUGIN_API QString FileFormatName();

extern "C" PLUGIN_API QStringList FileExtensions();

#include "htmlreader.h"

class HTMLIm 
{
public:
	HTMLIm(const QString& fname, const QString& encoding, gtWriter *w, bool textOnly);
	~HTMLIm();
private:
	QString encoding;
	QString filename;
	gtWriter *writer;
	gtParagraphStyle *pstyle;
// 	int defaultFontSize;
	void importText(bool textOnly);
};

#endif // HTMLIM_H
